@@ -12,11 +12,11 @@ use Scalar::Util 'weaken';
 has app => sub { Mojo::Server->new->build_app('Mojo::HelloWorld') };
 has 'backend';
 has backoff => sub { \&_backoff };
-has missing_after => 86400;
-has remove_after  => 864000;
+has missing_after => 1800;
+has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '4.06';
+our $VERSION = '5.0';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -115,12 +115,13 @@ Minion - Job queue
 =head1 DESCRIPTION
 
 L<Minion> is a job queue for the L<Mojolicious|http://mojolicious.org> real-time
-web framework with support for multiple named queues, priorities, delayed jobs,
-job results, retries with backoff, distributed workers, parallel processing and
-multiple backends (such as L<PostgreSQL|http://www.postgresql.org>).
+web framework, with support for multiple named queues, priorities, delayed jobs,
+job results, retries with backoff, statistics, distributed workers, parallel
+processing, autoscaling, resource leak protection and multiple backends (such as
+L<PostgreSQL|http://www.postgresql.org>).
 
-A job queue allows you to process time and/or computationally intensive tasks
-in background processes, outside of the request/response lifecycle. Among those
+Job queues allow you to process time and/or computationally intensive tasks in
+background processes, outside of the request/response lifecycle. Among those
 tasks you'll commonly find image resizing, spam filtering, HTTP downloads,
 building tarballs, warming caches and basically everything else you can imagine
 that's not super fast.
@@ -248,7 +249,7 @@ roughly C<25> attempts can be made in C<21> days.
 
 Amount of time in seconds after which workers without a heartbeat will be
 considered missing and removed from the registry by L</"repair">, defaults to
-C<86400> (1 day).
+C<1800> (30 minutes).
 
 =head2 remove_after
 
@@ -257,7 +258,7 @@ C<86400> (1 day).
 
 Amount of time in seconds after which jobs that have reached the state
 C<finished> will be removed automatically by L</"repair">, defaults to
-C<864000> (10 days).
+C<172800> (2 days).
 
 =head2 tasks
 
