@@ -11,18 +11,21 @@ sub run {
   my ($self, @args) = @_;
 
   GetOptionsFromArray \@args,
-    'I|heartbeat-interval=i' => \($self->{interval} = 60),
-    'j|jobs=i'               => \($self->{max}      = 4),
-    'q|queue=s'              => \my @queues;
+    'I|heartbeat-interval=i' => \($self->{hearthbeat} = 60),
+    'j|jobs=i'               => \($self->{max}        = 4),
+    'q|queue=s'              => \my @queues,
+    'R|repair-interval=i'    => \($self->{repair}     = 21600);
   $self->{queues} = @queues ? \@queues : ['default'];
 
   local $SIG{CHLD} = 'DEFAULT';
   local $SIG{INT} = local $SIG{TERM} = sub { $self->{finished}++ };
+  local $SIG{QUIT}
+    = sub { ++$self->{finished} and kill 'KILL', keys %{$self->{jobs}} };
 
   # Log fatal errors
   my $app = $self->app;
+  $app->log->debug("Worker $$ started");
   my $worker = $self->{worker} = $app->minion->worker;
-  @$self{qw(register repair)} = (0, 0);
   eval { $self->_work until $self->{finished} && !keys %{$self->{jobs}}; 1 }
     or $app->log->fatal("Worker error: $@");
   $worker->unregister;
@@ -33,16 +36,15 @@ sub _work {
 
   # Send heartbeats in regular intervals
   my $worker = $self->{worker};
-  $worker->register and $self->{register} = steady_time + $self->{interval}
-    if $self->{register} < steady_time;
+  $worker->register and $self->{register} = steady_time + $self->{hearthbeat}
+    if ($self->{register} || 0) < steady_time;
 
-  # Repair in regular intervals
-  if ($self->{repair} < steady_time) {
+  # Repair in regular intervals (randomize to avoid congestion)
+  if (($self->{check} || 0) < steady_time) {
     my $app = $self->app;
     $app->log->debug('Checking worker registry and job queue');
-    my $minion = $app->minion;
-    $minion->repair;
-    $self->{repair} = steady_time + $minion->missing_after;
+    my $repair = $self->{repair};
+    $self->{check} = steady_time + ($repair - int rand $repair / 2);
   }
 
   # Check if jobs are finished
@@ -54,7 +56,10 @@ sub _work {
 
   # Try to get more jobs
   elsif (my $job = $worker->dequeue(5 => {queues => $self->{queues}})) {
-    $jobs->{$job->start} = $job;
+    $jobs->{my $pid = $job->start} = $job;
+    my ($id, $task) = ($job->id, $job->task);
+    $self->app->log->debug(
+      qq{Performing job "$id" with task "$task" in process $pid});
   }
 }
 
@@ -71,7 +76,7 @@ Minion::Command::minion::worker - Minion worker command
   Usage: APPLICATION minion worker [OPTIONS]
 
     ./myapp.pl minion worker
-    ./myapp.pl minion worker -m production -I 15 -j 10
+    ./myapp.pl minion worker -m production -I 15 -R 3600 -j 10
     ./myapp.pl minion worker -q important -q default
 
   Options:
@@ -87,6 +92,7 @@ Minion::Command::minion::worker - Minion worker command
                                          MOJO_MODE/PLACK_ENV or "development"
     -q, --queue <name>                   One or more queues to get jobs from,
                                          defaults to "default"
+    -R, --repair-interval <seconds>      Repair interval, defaults to 21600
 
 =head1 DESCRIPTION
 
@@ -102,6 +108,10 @@ with the following signals.
 
 Stop gracefully after finishing the current jobs.
 
+=head2 QUIT
+
+Stop immediately without finishing the current jobs.
+
 =head1 ATTRIBUTES
 
 L<Minion::Command::minion::worker> inherits all attributes from
